@@ -12,8 +12,9 @@ from .util import u
 
 __all__ = ['parse', 'load', 'loads', 'dump', 'dumps']
 
-
-FM_RE = re.compile(r'^\s*---(.*)---\s*$', re.MULTILINE | re.DOTALL)
+# match three or more dashes
+# split on this
+FM_BOUNDARY = re.compile(r'^-{3,}$', re.MULTILINE)
 
 POST_TEMPLATE = """\
 ---
@@ -34,22 +35,23 @@ def parse(text, **defaults):
     # ensure unicode first
     text = u(text)
 
-    # match, returning empty metadata and the original content on failure
-    match = FM_RE.search(text)
-    if match is None:
-        return ({}, text)
-
-    # content is everything after metadata
-    content = text[match.end():].strip()
+    # split on the first two triple-dashes
+    try:
+        _, fm, content = FM_BOUNDARY.split(text, 2)
+    except ValueError:
+        # if we can't split, bail
+        return {}, text
 
     # metadata is a dictionary, with defaults
     metadata = {}
     metadata.update(defaults)
 
     # parse yaml
-    metadata.update(yaml.safe_load(match.groups()[0]))
+    fm = yaml.safe_load(fm)
+    if isinstance(fm, dict):
+        metadata.update(fm)
 
-    return metadata, content
+    return metadata, content.strip()
 
 
 def load(fd, **defaults):
@@ -123,8 +125,13 @@ class Post(object):
         return self.metadata.get(key, default)
 
     def keys(self):
+        "Return metadata keys"
         return self.metadata.keys()
 
+    def values(self):
+        "Return metadata values"
+        return self.metadata.values()
+
     def to_dict(self):
         "Post as a dict, for serializing"
         d = self.metadata.copy()
